@@ -1,7 +1,7 @@
 package App::wordlist;
 
-our $DATE = '2016-01-18'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2016-02-05'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use strict;
@@ -137,6 +137,8 @@ $SPEC{wordlist} = {
     'cmdline.default_format' => 'text-simple',
 };
 sub wordlist {
+    require Encode;
+
     my %args = @_;
 
     my $action = $args{action} // 'grep';
@@ -146,9 +148,9 @@ sub wordlist {
     my $arg = $args{arg} // [];
 
     if ($action eq 'grep') {
-
         # convert /.../ in arg to regex
         for (@$arg) {
+            $_ = Encode::decode('UTF-8', $_);
             if (m!\A/(.*)/\z!) {
                 $_ = $ci ? qr/$1/i : qr/$1/;
             } else {
@@ -277,7 +279,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.18 of App::wordlist (from Perl distribution App-wordlist), released on 2016-01-18.
+This document describes version 0.19 of App::wordlist (from Perl distribution App-wordlist), released on 2016-02-05.
 
 =head1 SYNOPSIS
 
